# ReconcileSubOrgIssuerRequest

A request to create or remove a sub org's issuer. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**own_issuer** | **bool** | Whether the suborg should have its own issuer. If true, an issuer is created for the suborg. If false, any unique issuer for the suborg is removed, and it is associated with its parent org&#39;s issuer.  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


